..
    This file is part of Invenio.
    Copyright (C) 2017-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. _users-guide:

User's Guide
------------

This part of the documentation will show you how to get started using Invenio.

.. toctree::
    :maxdepth: 2
    :name: mastertoc

    quickstart
    tutorial/index
    running
    loading
    accessing
    orcid-login
    migrating
